SPICE = [
    "allspice",
    "anise",
    "aniseed",
    "annatto",
    "asafoetida",
    "baharat",
    "caraway",
    "cardamom",
    "cassia",
    "cayenne",
    "celery seed",
    "chile",
    "chili",
    "chili powder",
    "chilli",
    "chilli powder",
    "chinese five spice",
    "chives",
    "cinnamon",
    "cloves",
    "coriander",
    "cumin",
    "curry",
    "dill",
    "fennel",
    "fenugreek",
    "five spice",
    "garam masala",
    "ginger",
    "horseradish",
    "juniper",
    "mace",
    "marjoram",
    # "mustard",
    "nutmeg",
    "oregano",
    "paprika",
    "pepper",
    "peppercorn",
    "poppy seed",
    "rosemary",
    "saffron",
    "sage",
    "sichuan pepper",
    "star anise",
    "sumac",
    "sumaq",
    "tamarind",
    "tarragon",
    "turmeric",
    "wasabi",
    "za'atar",
    "zatar",
]
