import re

DRINK_COCKTAILS = [
    "Acapulco",
    "Adios motherfucker",
    "Adonis",
    "blonde redhead",
    "sour",
    "slammer",
    "Alexander",
    "Amber moon",
    "Americano",
    "Ancient Mariner",
    "Angel face",
    "Aperol spritz",
    "Aperol sunrise",
    "Apple-kneel",
    "Appletini",
    "Agua de Sevilla",
    "Agua de Valencia",
    "Agua loca",
    "Aqua Velva",
    "Arizona Biltmore",
    "Astronaut sunrise",
    "Astro pop",
    "Aviation",
    "B-52",
    "B & B",
    "Baby Guinness",
    "Bacardi cocktail",
    "Backdraft",
    "Batida",
    "Bay breeze",
    "Bee's knees",
    "Bellini",
    "Between the sheets",
    "Bijou",
    "Black and tan",
    "Black nail",
    "Black Russian",
    "Black velvet",
    "Blackthorn",
    "Bloody Aztec",
    "Bloody Margaret",
    "Bloody Mary",
    "Blow my skull off",
    "BLT cocktail",
    "Blue blazer",
    "Blue Hawaii",
    "Blue Lagoon",
    "Blueberry tea",
    "Bobby Burns",
    "Boilermaker",
    "Boomerang",
    "Boulevardier",
    "Bourbon lancer",
    "Bramble",
    "Brandy Alexander",
    "Brandy sour / brandy daisy",
    "Brandy Manhattan",
    "Brandy sour",
    "Brave bull",
    "Breakfast martini",
    "Bronx",
    "Brooklyn",
    "Brut cocktail",
    "Buck's fizz",
    "Bull shot",
    "Bumbo",
    "Bushwacker",
    "Buttery nipple",
    # "Caesar",
    "Caipirinha",
    "Caipiroska",
    "Caju amigo",
    "Cape Codder",
    # "Carrot cake",
    "Casino",
    "Cement mixer",
    "Champagne cocktail",
    "Chatham Artillery punch",
    "Chi chi",
    "Chicago cocktail",
    "Chimayó cocktail",
    "Chocolate martini",
    "Churchill",
    "Cloister",
    "Clover Club cocktail",
    "Cobra's fang",
    "Cojito",
    "Colombia",
    "Colorado bulldog",
    "Common market",
    "Cooperstown cocktail",
    "Corpse reviver #2",
    "Cosmopolitan",
    "Cremat",
    "Cuba libre",
    "Cuban sunset",
    "Curaçao punch",
    "Daiquiri",
    "Damn the weather",
    "Dark 'n' stormy",
    "Death in the Afternoon",
    "Derby",
    "Diki-diki",
    "Doctor",
    "Duck fart",
    "El Presidente",
    "Enamorada sunrise",
    "Fish house punch",
    "Flaming Doctor Pepper",
    "Flaming sambuca",
    "Flaming volcano",
    "Flirtini",
    "Florida sunrise",
    "Fluffy critter",
    "Four score",
    "French 75",
    "French Connection",
    "Fuzzy navel",
    "Gibson",
    "Gimlet",
    "Gin and tonic",
    "Gin fizz",
    "Gin pahit",
    "Gin sour",
    "Ginza Mary",
    "Glowtini",
    "Godfather",
    "Godmother",
    "Golden doublet",
    "Golden dream",
    "Grasshopper ",
    "Grateful Dead",
    "Greyhound",
    "Grog",
    "Gunfire",
    "Hangman's blood",
    "Hanky panky",
    "Harlem mugger",
    "Harvey Wallbanger",
    "Hennchata",
    "Herbsaint frappé",
    "Horse's neck",
    "Horsefeather",
    "Hot buttered rum",
    "Hugo",
    "Hurricane",
    "Incredible Hulk",
    "Irish car bomb",
    "Irish coffee",
    "Jack and Coke",
    "Jack Rose",
    "Jägerbomb",
    "Jagertee",
    "Japanese slipper",
    "John Collins",
    "Juan Collins",
    "Jungle juice",
    "Kalimotxo",
    "Kamikaze",
    "Karsk",
    "Kensington Court special",
    "Kir",
    "Kir royal",
    "Leite de Onça",
    "Lemon drop",
    "Lime Rickey",
    "Link up",
    "Long Beach iced tea",
    "Long Island iced tea",
    "Lorraine",
    "Lynchburg lemonade",
    "Macuá",
    "Mai-Tai",
    "Malecon",
    "Mango sour",
    "Manhattan",
    "Margarita",
    "Martini",
    "Matador",
    "Mauresque",
    "Mexica",
    "Mexican martini",
    "Michelada",
    "Midori sour",
    "Mimosa",
    "Mint julep",
    "Mismo",
    "Missouri mule",
    "Mojito",
    "Mojito blanco",
    "Monaco",
    "Monkey gland",
    "Moonwalk",
    "Moscow mule",
    "Mr. Bali Hai",
    "Mudslide",
    "Mulled wine",
    "My Fair Lady",
    "Negroni",
    "Nixon",
    "Oatmeal cookie",
    "Old Etonian",
    "Old fashioned",
    "Orange tundra",
    "Orgasm",
    "Ouzini",
    "Painkiller",
    "Paloma",
    "Panama",
    "Paradise",
    "Pastis",
    "Perroquet",
    "Pegu",
    "Pimm's cup",
    "Piña colada",
    "Pink gin",
    "Pink lady",
    "Pisco sour",
    "Planter's punch",
    "Polar bear",
    "Porchcrawler",
    "Porn star martini",
    "Porto flip",
    "Prince of Wales",
    "Q.B. Cooler",
    "Queen Mary",
    "Quentão",
    "Quick fuck",
    "Rabo-de-galo",
    "fizz",
    "Rebujito",
    "Red Russian",
    "Redheaded slut",
    "Revelation",
    "Rob Roy",
    "Rose Kennedy",
    "Rossini",
    "Rourou",
    "Royal arrival",
    "Royal Bermuda",
    "Ruby dutchess",
    "Summer",
    "Rum swizzle",
    "Rusty nail",
    "Sake bomb",
    "Salty dog",
    "Sangria",
    "Savoy affair",
    "Savoy corpse reviver",
    "Sazerac",
    "Schneemaß",
    "Scotch and soda",
    "Screwdriver",
    "Sea breeze",
    "Sex on the beach",
    "Shandy",
    "Shirley Temple Black",
    "Sidecar",
    "Singapore sling",
    "Skittle bomb",
    "Slippery nipple",
    "Snakebite",
    "Snowball",
    "Springbokkie",
    "Spritzer",
    "Stinger",
    "Suffering bastard",
    "Sumatra Kula",
    "Tamagozake",
    "Tamango",
    "Tequila slammer",
    "Tequila sour",
    "Tequila sunrise",
    "Tequila sunset",
    "Test pilot",
    "The Blenheim",
    "The last word",
    "Three wise men",
    "Ti' punch",
    "Tinto de Verano",
    "Tokyo iced tea",
    "Tom and Jerry",
    "Tom Collins",
    "Tomate",
    "Tommy's margarita",
    "Toronto",
    "Trumptini",
    "Tschunk",
    "Tuxedo",
    "U-boot",
    "Up to date",
    "Vampiro",
    "Vesper",
    "Vodka gimlet",
    "Vodka martini",
    "Vodka sunrise",
    "Ward 8",
    "Whiskey sour",
    "Whisky Mac",
    "White lady or Delilah",
    "White Russian",
    "Wolfram",
    "Woo woo",
    "Yellow bird",
    "Yorsh",
    "Zombie",
    "Zurracapote",
    r"(?<!lobster )(?<!prawn )(?<!crab )(?<!mussel )(?<!shrimp )(?<!scallop )(?<!oyster )cocktail",
]

DRINK_ALCO = [
    "absinthe",
    "amaretto",
    "apple brandy",
    "applejack",
    "aquavit",
    "armagnac",
    "beer",
    "benedictine",
    "blackberry brandy",
    "blackberry schnapps",
    "blue curacao",
    "bourbon",
    "brandy",
    "calvados",
    "campari",
    "cachaca",
    "cointreau",
    "champagne",
    "cherry brandy",
    "cherry heering",
    "chocolate liqueur",
    "cider",
    "cognac",
    "cointreau",
    "curacao",
    "drambuie",
    "dry vermouth",
    "dubonnet blanc",
    "dubonnet rouge",
    "everclear",
    "frangelico",
    "galliano",
    "galleano",
    "gin",
    "grand marnier",
    "grape brandy",
    "green chartreuse",
    "grenadine",
    "honey liqueur",
    "hot chocolate",
    "irish cream",
    "jagermeister",
    "kahlua",
    "kirsch",
    "kummel",
    "lemon vodka",
    "lemonade",
    "light rum",
    "lime juice",
    "madeira",
    "malibu rum",
    "mandarin vodka",
    "maraschino liqueur",
    "mezcal",
    "midori melon liqueur",
    "mint schnapps",
    "orange bitters",
    "orange curacao",
    "orange liqueur",
    "orange rum",
    "orange vodka",
    "ouzo",
    "pernod",
    "pineapple juice",
    "pineapple rum",
    "pineapple vodka",
    "port",
    "punch",
    "red wine",
    "rock and rye",
    "rum",
    "rye whiskey",
    "sake",
    "sambuca",
    "sherry",
    "sloe gin",
    "southern comfort",
    "spiced rum",
    "strawberry liqueur",
    "strawberry schnapps",
    "sweet vermouth",
    "tequila",
    "triple sec",
    "vanilla liqueur",
    "vanilla vodka",
    "vermouth",
    "vodka",
    "watermelon schnapps",
    "whiskey",
    "white creme de cacao",
    "white rum",
    "white wine",
    "wildberry schnapps",
    "wine",
    "yellow chartreuse",
    "yukon jack",
    "zima",
]

DRINK_NON_ALCO = [
    "coffee",
    "cola",
    "cappuccino",
    "hot chocolate",
    "lungo",
    "macchiato",
    "milk",
    "mocha",
    "tea",
    "americano",
    "espresso",
    "iced tea",
    "juice",
    "lemonade",
    "orangeade",
    "soda",
    "pop",
    "sprite",
    "tonic",
    "water",
    "slushy",
    "slushie",
    "colada",
    "bitter",
    "frappe",
    "frappuccino",
    "rootbeer",
    "drink",
    "shake",
    "milkshake",
    "smoothie",
    "smoothy",
    "cocoa",
]


DRINKS = [
    *DRINK_ALCO,
    *DRINK_NON_ALCO,
    *DRINK_COCKTAILS,
]

RE_DRINK = (r"\b(?:" + r"|".join([re.escape(x) for x in DRINKS]) + r")(?:es|s)?$",)
